# Generated by Django 2.0.5 on 2018-06-04 08:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Feature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('slug', models.SlugField(default='')),
                ('model_verbose_name', models.CharField(default='', max_length=255)),
                ('limit', models.IntegerField(default=0)),
                ('template', models.CharField(default='', max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='Query',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('field_verbose_name', models.CharField(default='', max_length=255)),
                ('filter_criteria', models.CharField(choices=[('Equals', 'Equals'), ('Greater than', 'Greater than'), ('Less than', 'Less than'), ('Range', 'Range'), ('Contains', 'Contains')], default='', max_length=255)),
                ('filter_value', models.CharField(default='', max_length=255)),
                ('feature', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='qb.Feature')),
            ],
            options={
                'verbose_name_plural': 'Queries',
            },
        ),
    ]
