# Generated by Django 2.0.7 on 2018-07-12 14:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qb', '0005_auto_20180704_1840'),
    ]

    operations = [
        migrations.AddField(
            model_name='feature',
            name='order_by',
            field=models.CharField(default='', max_length=255),
        ),
    ]
