# Generated by Django 2.0.7 on 2018-07-04 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qb', '0004_auto_20180704_1447'),
    ]

    operations = [
        migrations.AlterField(
            model_name='query',
            name='filter_value',
            field=models.CharField(blank=True, default=None, max_length=255),
        ),
    ]
