# Generated by Django 2.0.7 on 2018-07-04 12:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qb', '0003_auto_20180607_1638'),
    ]

    operations = [
        migrations.AlterField(
            model_name='query',
            name='join',
            field=models.CharField(choices=[('-', '-'), ('AND', 'AND'), ('OR', 'OR')], default='-', max_length=255),
        ),
    ]
