# Generated by Django 2.0.5 on 2018-06-07 14:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qb', '0002_contact'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contact',
            options={},
        ),
        migrations.AddField(
            model_name='query',
            name='join',
            field=models.CharField(choices=[('OR', 'OR'), ('AND', 'AND')], default='', max_length=255),
        ),
        migrations.AlterField(
            model_name='query',
            name='filter_criteria',
            field=models.CharField(choices=[('Equals', 'Equals'), ('Greater than', 'Greater than'), ('Less than', 'Less than'), ('Contains', 'Contains')], default='', max_length=255),
        ),
    ]
